@@ -543,7 +543,7 @@ def FieldDetermination(Fields=1,plot=False,**kwargs):
         for i in range(len(rect)):
             ax.add_patch(rect[i])
 
-    if ret == True:
+    if ret:
             return fields
 
 def Interaction(data,bodyPart,fields,fps=30):
@@ -1171,7 +1171,8 @@ def PlotInteraction(interactions, **kwargs):
     plt.yticks([])
     plt.xticks(fontsize = fontsize*0.8)
     plt.xlabel("Time (s)",fontsize=fontsize)
-    plt.ylim([-barHeight,barHeight])
+    plt.ylim([barHeight,barHeight])
+    plt.title(figureTitle,fontsize=fontsize)
     plt.show()
     if type(saveName) != type(None):
         plt.savefig(saveName+figformat)
@@ -1184,7 +1185,7 @@ def PlotInteraction(interactions, **kwargs):
     ax.get_yaxis().set_visible(False)
     ax.tick_params(axis='x', labelsize=fontsize*.8)
     ax.tick_params(axis='y', labelsize=fontsize*.8)
-    ax.legend(ncol=int(interactions.obj.max()),fontsize=fontsize)
+    ax.legend(ncol=int(interactions.obj.max()),fontsize=fontsize*.8)
     ax.set_xlabel('Time (s)',fontsize=fontsize)
-
+    ax.set_title(figureTitle,fontsize=fontsize)
     ax.set_ylim([-barHeight,barHeight])
